=============================================================================
 `xotl.tools.fp.iterators`:mod: -- High-level functional tools for iterators
=============================================================================

.. automodule:: xotl.tools.fp.iterators
   :members: kleisli_compose, kleisli_compose_foldl

.. function:: iter_compose

   .. deprecated:: 1.9.7 Alias of `xotl.tools.fp.iterators.kleisli_compose`:func:
